@@ -23,13 +23,11 @@ class MarketApi(IMarketApi):
 
         self.__event_bus = event_bus
 
-        #自动重连检测时间
-        self.__AutoReconnectInterval = 10
-
         cfg = websocketCfg()
         cfg.address = Environment.get_instance().get_quoteaddr()
         cfg.hbContent = json.dumps({ 'requestType' : 'HeartBeat','reqID' : '' })
         cfg.recvCallback = self.__OnRecv
+        cfg.connectedCallback = self.__AuotSubscribe
         self.__wsClient = WebSocketClient(cfg)
         self.__subscribes = []
         self.__responseMsgCache = MemCache()
@@ -39,26 +37,18 @@ class MarketApi(IMarketApi):
         if not self.__wsClient.Connect():
             logger.error("market connect failed!")
             return False
-        t = threading.Thread(target=self.__AuotReconnect,args=(self.__wsClient,))
-        t.start()
+        self.__wsClient.AutoHeartBeat()
         return True
 
-    def __AuotReconnect(self,client):
-        """自动连接"""
-        while True:
-            try:
-                if not client.IsConnected():
-                    logger.debug("未连接，尝试连接...")
-                    ret = client.Connect()
-                    logger.debug("重连完成：{0}".format(ret))
-
-                    if len(self.__subscribes) > 0:
-                        logger.debug("连接成功，开始订阅...")
-                        subRet = self.Subscribe(*self.__subscribes)
-                        logger.debug("连接成功，订阅完成：{0}".format(subRet))
-            except Exception as e:
-                logger.error(e)
-            time.sleep(self.__AutoReconnectInterval)
+    def __AuotSubscribe(self):
+        """自动订阅"""
+        try:
+            if len(self.__subscribes) > 0:
+                logger.debug("连接成功，开始订阅...")
+                subRet = self.Subscribe(*self.__subscribes)
+                logger.debug("连接成功，订阅完成：{0}".format(subRet))
+        except Exception as e:
+            logger.error(e)
 
     def __OnRecv(self,msg):
         '''收到行情消息'''
@@ -94,7 +84,7 @@ class MarketApi(IMarketApi):
         if not subInfos:
             logger.error('订阅参数不能为空')
             return False
-        if not self.__wsClient.IsConnected():
+        if not self.__wsClient.IsAvaliable():
             logger.error('行情未连接')
             return False
         req = SubscribeReq()
