@@ -20,22 +20,21 @@ class MemCache(object):
         while True:
             time.sleep(10)
             if not self.lock.acquire(timeout=0.1):
-                logutil.writeLog("MemCacheError", '获取锁失败')
+                logger.error('memcache acquire lock failed!')
                 continue
             try:
                 for key in list(self.mem.keys()):
                     if self.time[key] != -1 and self.time[key] <= time.time():
                         self.delete(key)
             except Exception as e:
-                logutil.writeLog("MemCacheError", str(e))
-                logutil.writeLog("MemCacheError", traceback.format_exc())
+                logger.error(e)
             finally:
                 self.lock.release()
 
     def set(self, key, data, age=-1):
         '''保存键为key的值，时间位age'''
         if not self.lock.acquire(timeout=0.1):
-            logutil.writeLog("MemCacheError", '获取锁失败')
+            logger.error('memcache acquire lock failed!')
             return False
         try:
             self.mem[key] = data
@@ -50,7 +49,7 @@ class MemCache(object):
     def get(self,key):
         '''获取键key对应的值'''
         if not self.lock.acquire(timeout=0.1):
-            logutil.writeLog("MemCacheError", '获取锁失败')
+            logger.error('memcache acquire lock failed!')
             return None
         try:
             if key in self.mem.keys():
@@ -67,7 +66,7 @@ class MemCache(object):
     def delete(self,key):
         '''删除键为key的条目'''
         if not self.lock.acquire(timeout=0.1):
-            logutil.writeLog("MemCacheError", '获取锁失败')
+            logger.error('memcache acquire lock failed!')
             return True
         try:
             if key in self.mem.keys():
@@ -81,7 +80,7 @@ class MemCache(object):
     def clear(self):
         '''清空所有缓存'''
         if not self.lock.acquire(timeout=0.1):
-            logutil.writeLog("MemCacheError", '获取锁失败')
+            logger.error('memcache acquire lock failed!')
             return
         try:
             self.mem.clear()
